@@ -6,16 +6,15 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "monitormanager.h"
 #include "core.h"
-#include "doc/kdenlivedoc.h"
 #include "kdenlivesettings.h"
 #include "mainwindow.h"
+#include "monitorproxy.h"
 #include "timeline2/view/timelinewidget.h"
 
 #include <mlt++/Mlt.h>
 
 #include "klocalizedstring.h"
 #include <KDualAction>
-#include <kwidgetsaddons_version.h>
 
 #include "kdenlive_debug.h"
 #include <QObject>
@@ -119,9 +118,9 @@ void MonitorManager::refreshProjectRange(QPair<int, int> range, bool forceRefres
     }
 }
 
-void MonitorManager::refreshProjectMonitor(bool directUpdate)
+void MonitorManager::refreshProjectMonitor(bool directUpdate, bool slowUpdate)
 {
-    m_projectMonitor->refreshMonitor(directUpdate);
+    m_projectMonitor->refreshMonitor(directUpdate, slowUpdate);
 }
 
 void MonitorManager::refreshClipMonitor(bool directUpdate)
@@ -287,6 +286,15 @@ void MonitorManager::slotPlayZone()
     }
 }
 
+void MonitorManager::slotPlayZoneFromCursor()
+{
+    if (m_activeMonitor == m_clipMonitor) {
+        m_clipMonitor->slotPlayZone(false);
+    } else if (m_activeMonitor == m_projectMonitor) {
+        m_projectMonitor->slotPlayZone(false);
+    }
+}
+
 void MonitorManager::slotLoopZone()
 {
     if (m_activeMonitor == m_clipMonitor) {
@@ -480,7 +488,7 @@ AbstractMonitor *MonitorManager::activeMonitor()
 void MonitorManager::slotSwitchFullscreen()
 {
     if (m_activeMonitor) {
-        m_activeMonitor->slotSwitchFullScreen();
+        QMetaObject::invokeMethod(m_activeMonitor, "slotSwitchFullScreen", Qt::QueuedConnection);
     }
 }
 
@@ -838,3 +846,13 @@ void MonitorManager::updateBgColor()
         m_clipMonitor->forceMonitorRefresh();
     }
 }
+
+void MonitorManager::updateGrid()
+{
+    if (m_projectMonitor) {
+        Q_EMIT m_projectMonitor->getControllerProxy()->gridChanged();
+    }
+    if (m_clipMonitor) {
+        Q_EMIT m_clipMonitor->getControllerProxy()->gridChanged();
+    }
+}
