@@ -32,8 +32,6 @@ ClipModel::ClipModel(const std::shared_ptr<TimelineModel> &parent, std::shared_p
     , forceThumbReload(false)
     , m_currentState(state)
     , m_speed(speed)
-    , m_fakeTrack(-1)
-    , m_fakePosition(-1)
     , m_positionOffset(0)
     , m_subPlaylistIndex(0)
     , m_mixDuration(0)
@@ -1135,6 +1133,11 @@ int ClipModel::fadeOut() const
     return m_effectStack->getFadePosition(false);
 }
 
+int ClipModel::fadeMethod(bool fadeIn) const
+{
+    return m_effectStack->getFadeMethod(fadeIn);
+}
+
 double ClipModel::getSpeed() const
 {
     return m_speed;
@@ -1317,26 +1320,6 @@ const QStringList ClipModel::externalFiles() const
     return m_effectStack->externalFiles();
 }
 
-int ClipModel::getFakeTrackId() const
-{
-    return m_fakeTrack;
-}
-
-void ClipModel::setFakeTrackId(int fid)
-{
-    m_fakeTrack = fid;
-}
-
-int ClipModel::getFakePosition() const
-{
-    return m_fakePosition;
-}
-
-void ClipModel::setFakePosition(int fpos)
-{
-    m_fakePosition = fpos;
-}
-
 QDomElement ClipModel::toXml(QDomDocument &document)
 {
     QDomElement container = document.createElement(QStringLiteral("clip"));
@@ -1584,3 +1567,21 @@ std::shared_ptr<KeyframeModelList> ClipModel::getKFModel(int row)
     std::shared_ptr<EffectItemModel> eff = std::static_pointer_cast<EffectItemModel>(item);
     return eff->getKeyframeModel();
 }
+
+const QString ClipModel::activeEffectId() const
+{
+    int activeEffect = m_effectStack->getActiveEffect();
+    if (activeEffect > -1) {
+        std::shared_ptr<AbstractEffectItem> item = m_effectStack->getEffectStackRow(activeEffect);
+        if (item) {
+            std::shared_ptr<EffectItemModel> eff = std::static_pointer_cast<EffectItemModel>(item);
+            return eff->getAssetId();
+        }
+    }
+    return QString();
+}
+
+void ClipModel::setActiveEffect(int row)
+{
+    m_effectStack->setActiveEffect(row);
+}
